@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="pt_BR" sourcelanguage="">
+<TS version="2.1" language="pt_BR">
   <context>
     <name>ConfigDialog</name>
     <message>
@@ -198,7 +198,7 @@
     <message>
       <location filename="../dialogs.py" line="63" />
       <source>Enter encoding name:</source>
-      <translation type="unfinished" />
+      <translation>Insira o nome da codificação:</translation>
     </message>
   </context>
   <context>
@@ -245,7 +245,7 @@
     <message>
       <location filename="../dialogs.py" line="44" />
       <source>It is possible to specify multiple languages, separated by comma.</source>
-      <translation type="unfinished" />
+      <translation>É possível especificar vários idiomas, separados por vírgula.</translation>
     </message>
     <message>
       <location filename="../dialogs.py" line="50" />
@@ -287,22 +287,22 @@
   <context>
     <name>ReTextTab</name>
     <message>
-      <location filename="../tab.py" line="173" />
+      <location filename="../tab.py" line="174" />
       <source>New document</source>
       <translation>Novo documento</translation>
     </message>
     <message>
-      <location filename="../tab.py" line="178" />
+      <location filename="../tab.py" line="179" />
       <source>Could not parse file contents, check if you have the &lt;a href="%s"&gt;necessary module&lt;/a&gt; installed!</source>
       <translation>Não foi possível analisar o conteúdo do arquivo, verifique se você tem o &lt;a href="%s"&gt;módulo necessário&lt;/a&gt; instalado!</translation>
     </message>
     <message>
-      <location filename="../tab.py" line="483" />
+      <location filename="../tab.py" line="489" />
       <source>Create missing file?</source>
       <translation>Criar arquivo ausente?</translation>
     </message>
     <message>
-      <location filename="../tab.py" line="484" />
+      <location filename="../tab.py" line="490" />
       <source>The file '%s' does not exist.
 
 Do you want to create it?</source>
@@ -311,12 +311,12 @@ Do you want to create it?</source>
 Deseja criá-lo?</translation>
     </message>
     <message>
-      <location filename="../tab.py" line="516" />
+      <location filename="../tab.py" line="522" />
       <source>File could not be created</source>
       <translation>Arquivo não pode ser criado</translation>
     </message>
     <message>
-      <location filename="../tab.py" line="517" />
+      <location filename="../tab.py" line="523" />
       <source>Could not create file '%s': %s</source>
       <translation>Não foi possível criar arquivo '%s': %s</translation>
     </message>
@@ -559,7 +559,7 @@ Deseja criá-lo?</translation>
     <message>
       <location filename="../window.py" line="219" />
       <source>What's new</source>
-      <translation type="unfinished" />
+      <translation>O que há de novo</translation>
     </message>
     <message>
       <location filename="../window.py" line="220" />
@@ -782,7 +782,7 @@ Gostaria de recarregar o arquivo? (isso descartará suas alterações)
     <message>
       <location filename="../window.py" line="1182" />
       <source>Automatic saving has been temporarily disabled for this tab to prevent data loss. It will be re-enabled when you reload the file or save it manually.</source>
-      <translation type="unfinished" />
+      <translation>O salvamento automático foi desabilitado temporariamente para esta aba para prevenir a perda de dados. É possível reabilitar enquanto carregar o arquivo ou salvá-lo manualmente.</translation>
     </message>
     <message>
       <location filename="../window.py" line="1205" />
@@ -830,7 +830,7 @@ Deseja salvar as alterações?</translation>
   <context>
     <name>TextInfoArea</name>
     <message>
-      <location filename="../editor.py" line="654" />
+      <location filename="../editor.py" line="659" />
       <source>%d w | %d a | %d c</source>
       <comment>count of words, alphanumeric characters, all characters</comment>
       <translation>%d p | %d a | %d c</translation>
