@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="tr_TR" sourcelanguage="">
+<TS version="2.1" language="tr_TR">
   <context>
     <name>ConfigDialog</name>
     <message>
@@ -198,7 +198,7 @@
     <message>
       <location filename="../dialogs.py" line="63" />
       <source>Enter encoding name:</source>
-      <translation type="unfinished" />
+      <translation>Kodlama adını girin:</translation>
     </message>
   </context>
   <context>
@@ -245,7 +245,7 @@
     <message>
       <location filename="../dialogs.py" line="44" />
       <source>It is possible to specify multiple languages, separated by comma.</source>
-      <translation type="unfinished" />
+      <translation>Virgülle ayırarak birden çok dil belirtmek mümkündür.</translation>
     </message>
     <message>
       <location filename="../dialogs.py" line="50" />
@@ -287,22 +287,22 @@
   <context>
     <name>ReTextTab</name>
     <message>
-      <location filename="../tab.py" line="173" />
+      <location filename="../tab.py" line="174" />
       <source>New document</source>
       <translation>Yeni belge</translation>
     </message>
     <message>
-      <location filename="../tab.py" line="178" />
+      <location filename="../tab.py" line="179" />
       <source>Could not parse file contents, check if you have the &lt;a href="%s"&gt;necessary module&lt;/a&gt; installed!</source>
       <translation>Dosya içeriği ayrıştırılamadı, &lt;a href="%s"&gt;gerekli modülün&lt;/a&gt; kurulu olup olmadığını kontrol edin!</translation>
     </message>
     <message>
-      <location filename="../tab.py" line="483" />
+      <location filename="../tab.py" line="489" />
       <source>Create missing file?</source>
       <translation>Eksik dosya oluşturulsun mu?</translation>
     </message>
     <message>
-      <location filename="../tab.py" line="484" />
+      <location filename="../tab.py" line="490" />
       <source>The file '%s' does not exist.
 
 Do you want to create it?</source>
@@ -311,12 +311,12 @@ Do you want to create it?</source>
 Onu oluşturmak ister misin?</translation>
     </message>
     <message>
-      <location filename="../tab.py" line="516" />
+      <location filename="../tab.py" line="522" />
       <source>File could not be created</source>
       <translation>Dosya oluşturulamadı</translation>
     </message>
     <message>
-      <location filename="../tab.py" line="517" />
+      <location filename="../tab.py" line="523" />
       <source>Could not create file '%s': %s</source>
       <translation>'%s' dosyası oluşturulamadı: %s</translation>
     </message>
@@ -559,7 +559,7 @@ Onu oluşturmak ister misin?</translation>
     <message>
       <location filename="../window.py" line="219" />
       <source>What's new</source>
-      <translation type="unfinished" />
+      <translation>Neler yeni</translation>
     </message>
     <message>
       <location filename="../window.py" line="220" />
@@ -782,7 +782,7 @@ Dosyayı yeniden yüklemek istiyor musunuz (bu, tüm değişikliklerinizi atacak
     <message>
       <location filename="../window.py" line="1182" />
       <source>Automatic saving has been temporarily disabled for this tab to prevent data loss. It will be re-enabled when you reload the file or save it manually.</source>
-      <translation type="unfinished" />
+      <translation>Veri kaybını önlemek için bu sekme için otomatik kaydetme geçici olarak devre dışı bırakıldı. Dosyayı yeniden yüklediğinizde veya kaydettiğinizde yeniden etkinleştirilecektir.</translation>
     </message>
     <message>
       <location filename="../window.py" line="1205" />
@@ -809,7 +809,7 @@ Değişikliklerinizi kaydetmek istiyor musunuz?</translation>
     <message>
       <location filename="../window.py" line="1265" />
       <source>Simple but powerful editor for Markdown and reStructuredText</source>
-      <translation>Markdown ve reStructuredText için basit ama güçlü düzenleyici</translation>
+      <translation>Markdown ve Yeniden Yapılandırılmış Metin için basit ama güçlü düzenleyici</translation>
     </message>
     <message>
       <location filename="../window.py" line="1267" />
@@ -830,7 +830,7 @@ Değişikliklerinizi kaydetmek istiyor musunuz?</translation>
   <context>
     <name>TextInfoArea</name>
     <message>
-      <location filename="../editor.py" line="654" />
+      <location filename="../editor.py" line="659" />
       <source>%d w | %d a | %d c</source>
       <comment>count of words, alphanumeric characters, all characters</comment>
       <translation>%d w | %d a | %d c</translation>
